==> open_iconic_flutter-0.1.0.tar.gz: lib/open_iconic_flutter.dart <==
library open_iconic_flutter;

import 'package:flutter/material.dart';

class OpenIconicIcons {
  static const IconData accountLogin = const _IconData(0xe000);
  static const IconData accountLogout = const _IconData(0xe001);
  static const IconData actionRedo = const _IconData(0xe002);
  static const IconData actionUndo = const _IconData(0xe003);
  static const IconData alignCenter = const _IconData(0xe004);
  static const IconData alignLeft = const _IconData(0xe005);
  static const IconData alignRight = const _IconData(0xe006);
  static const IconData aperture = const _IconData(0xe007);
  static const IconData arrowBottom = const _IconData(0xe008);
  static const IconData arrowCircleBottom = const _IconData(0xe009);
  static const IconData arrowCircleLeft = const _IconData(0xe00a);
  static const IconData arrowCircleRight = const _IconData(0xe00b);
  static const IconData arrowCircleTop = const _IconData(0xe00c);
  static const IconData arrowLeft = const _IconData(0xe00d);
  static const IconData arrowRight = const _IconData(0xe00e);
  static const IconData arrowThickBottom = const _IconData(0xe00f);
  static const IconData arrowThickLeft = const _IconData(0xe010);
  static const IconData arrowThickRight = const _IconData(0xe011);
  static const IconData arrowThickTop = const _IconData(0xe012);
  static const IconData arrowTop = const _IconData(0xe013);
  static const IconData audioSpectrum = const _IconData(0xe014);
  static const IconData audio = const _IconData(0xe015);
  static const IconData badge = const _IconData(0xe016);
  static const IconData ban = const _IconData(0xe017);
  static const IconData barChart = const _IconData(0xe018);
  static const IconData basket = const _IconData(0xe019);
  static const IconData batteryEmpty = const _IconData(0xe01a);
  static const IconData batteryFull = const _IconData(0xe01b);
  static const IconData beaker = const _IconData(0xe01c);
  static const IconData bell = const _IconData(0xe01d);
  static const IconData bluetooth = const _IconData(0xe01e);
  static const IconData bold = const _IconData(0xe01f);
  static const IconData bolt = const _IconData(0xe020);
  static const IconData book = const _IconData(0xe021);
  static const IconData bookmark = const _IconData(0xe022);
  static const IconData box = const _IconData(0xe023);
  static const IconData briefcase = const _IconData(0xe024);
  static const IconData britishPound = const _IconData(0xe025);
  static const IconData browser = const _IconData(0xe026);
  static const IconData brush = const _IconData(0xe027);
  static const IconData bug = const _IconData(0xe028);
  static const IconData bullhorn = const _IconData(0xe029);
  static const IconData calculator = const _IconData(0xe02a);
  static const IconData calendar = const _IconData(0xe02b);
  static const IconData cameraSlr = const _IconData(0xe02c);
  static const IconData caretBottom = const _IconData(0xe02d);
  static const IconData caretLeft = const _IconData(0xe02e);
  static const IconData caretRight = const _IconData(0xe02f);
  static const IconData caretTop = const _IconData(0xe030);
  static const IconData cart = const _IconData(0xe031);
  static const IconData chat = const _IconData(0xe032);
  static const IconData check = const _IconData(0xe033);
  static const IconData chevronBottom = const _IconData(0xe034);
  static const IconData chevronLeft = const _IconData(0xe035);
  static const IconData chevronRight = const _IconData(0xe036);
  static const IconData chevronTop = const _IconData(0xe037);
  static const IconData circleCheck = const _IconData(0xe038);
  static const IconData circleX = const _IconData(0xe039);
  static const IconData clipboard = const _IconData(0xe03a);
  static const IconData clock = const _IconData(0xe03b);
  static const IconData cloudDownload = const _IconData(0xe03c);
  static const IconData cloudUpload = const _IconData(0xe03d);
  static const IconData cloud = const _IconData(0xe03e);
  static const IconData cloudy = const _IconData(0xe03f);
  static const IconData code = const _IconData(0xe040);
  static const IconData cog = const _IconData(0xe041);
  static const IconData collapseDown = const _IconData(0xe042);
  static const IconData collapseLeft = const _IconData(0xe043);
  static const IconData collapseRight = const _IconData(0xe044);
  static const IconData collapseUp = const _IconData(0xe045);
  static const IconData command = const _IconData(0xe046);
  static const IconData commentSquare = const _IconData(0xe047);
  static const IconData compass = const _IconData(0xe048);
  static const IconData contrast = const _IconData(0xe049);
  static const IconData copywriting = const _IconData(0xe04a);
  static const IconData creditCard = const _IconData(0xe04b);
  static const IconData crop = const _IconData(0xe04c);
  static const IconData dashboard = const _IconData(0xe04d);
  static const IconData dataTransferDownload = const _IconData(0xe04e);
  static const IconData dataTransferUpload = const _IconData(0xe04f);
  static const IconData delete = const _IconData(0xe050);
  static const IconData dial = const _IconData(0xe051);
  static const IconData document = const _IconData(0xe052);
  static const IconData dollar = const _IconData(0xe053);
  static const IconData doubleQuoteSansLeft = const _IconData(0xe054);
  static const IconData doubleQuoteSansRight = const _IconData(0xe055);
  static const IconData doubleQuoteSerifLeft = const _IconData(0xe056);
  static const IconData doubleQuoteSerifRight = const _IconData(0xe057);
  static const IconData droplet = const _IconData(0xe058);
  static const IconData eject = const _IconData(0xe059);
  static const IconData elevator = const _IconData(0xe05a);
  static const IconData ellipses = const _IconData(0xe05b);
  static const IconData envelopeClosed = const _IconData(0xe05c);
  static const IconData envelopeOpen = const _IconData(0xe05d);
  static const IconData euro = const _IconData(0xe05e);
  static const IconData excerpt = const _IconData(0xe05f);
  static const IconData expandDown = const _IconData(0xe060);
  static const IconData expandLeft = const _IconData(0xe061);
  static const IconData expandRight = const _IconData(0xe062);
  static const IconData expandUp = const _IconData(0xe063);
  static const IconData externalLink = const _IconData(0xe064);
  static const IconData eye = const _IconData(0xe065);
  static const IconData eyedropper = const _IconData(0xe066);
  static const IconData file = const _IconData(0xe067);
  static const IconData fire = const _IconData(0xe068);
  static const IconData flag = const _IconData(0xe069);
  static const IconData flash = const _IconData(0xe06a);
  static const IconData folder = const _IconData(0xe06b);
  static const IconData fork = const _IconData(0xe06c);
  static const IconData fullscreenEnter = const _IconData(0xe06d);
  static const IconData fullscreenExit = const _IconData(0xe06e);
  static const IconData globe = const _IconData(0xe06f);
  static const IconData graph = const _IconData(0xe070);
  static const IconData gridFourUp = const _IconData(0xe071);
  static const IconData gridThreeUp = const _IconData(0xe072);
  static const IconData gridTwoUp = const _IconData(0xe073);
  static const IconData hardDrive = const _IconData(0xe074);
  static const IconData header = const _IconData(0xe075);
  static const IconData headphones = const _IconData(0xe076);
  static const IconData heart = const _IconData(0xe077);
  static const IconData home = const _IconData(0xe078);
  static const IconData image = const _IconData(0xe079);
  static const IconData inbox = const _IconData(0xe07a);
  static const IconData infinity = const _IconData(0xe07b);
  static const IconData info = const _IconData(0xe07c);
  static const IconData italic = const _IconData(0xe07d);
  static const IconData justifyCenter = const _IconData(0xe07e);
  static const IconData justifyLeft = const _IconData(0xe07f);
  static const IconData justifyRight = const _IconData(0xe080);
  static const IconData key = const _IconData(0xe081);
  static const IconData laptop = const _IconData(0xe082);
  static const IconData layers = const _IconData(0xe083);
  static const IconData lightbulb = const _IconData(0xe084);
  static const IconData linkBroken = const _IconData(0xe085);
  static const IconData linkIntact = const _IconData(0xe086);
  static const IconData listRich = const _IconData(0xe087);
  static const IconData list = const _IconData(0xe088);
  static const IconData location = const _IconData(0xe089);
  static const IconData lockLocked = const _IconData(0xe08a);
  static const IconData lockUnlocked = const _IconData(0xe08b);
  static const IconData loopCircular = const _IconData(0xe08c);
  static const IconData loopSquare = const _IconData(0xe08d);
  static const IconData loop = const _IconData(0xe08e);
  static const IconData magnifyingGlass = const _IconData(0xe08f);
  static const IconData mapMarker = const _IconData(0xe090);
  static const IconData map = const _IconData(0xe091);
  static const IconData mediaPause = const _IconData(0xe092);
  static const IconData mediaPlay = const _IconData(0xe093);
  static const IconData mediaRecord = const _IconData(0xe094);
  static const IconData mediaSkipBackward = const _IconData(0xe095);
  static const IconData mediaSkipForward = const _IconData(0xe096);
  static const IconData mediaStepBackward = const _IconData(0xe097);
  static const IconData mediaStepForward = const _IconData(0xe098);
  static const IconData mediaStop = const _IconData(0xe099);
  static const IconData medicalCross = const _IconData(0xe09a);
  static const IconData menu = const _IconData(0xe09b);
  static const IconData microphone = const _IconData(0xe09c);
  static const IconData minus = const _IconData(0xe09d);
  static const IconData monitor = const _IconData(0xe09e);
  static const IconData moon = const _IconData(0xe09f);
  static const IconData move = const _IconData(0xe0a0);
  static const IconData musicalNote = const _IconData(0xe0a1);
  static const IconData paperclip = const _IconData(0xe0a2);
  static const IconData pencil = const _IconData(0xe0a3);
  static const IconData people = const _IconData(0xe0a4);
  static const IconData person = const _IconData(0xe0a5);
  static const IconData phone = const _IconData(0xe0a6);
  static const IconData pieChart = const _IconData(0xe0a7);
  static const IconData pin = const _IconData(0xe0a8);
  static const IconData playCircle = const _IconData(0xe0a9);
  static const IconData plus = const _IconData(0xe0aa);
  static const IconData powerStandby = const _IconData(0xe0ab);
  static const IconData print = const _IconData(0xe0ac);
  static const IconData project = const _IconData(0xe0ad);
  static const IconData pulse = const _IconData(0xe0ae);
  static const IconData puzzlePiece = const _IconData(0xe0af);
  static const IconData questionMark = const _IconData(0xe0b0);
  static const IconData rain = const _IconData(0xe0b1);
  static const IconData random = const _IconData(0xe0b2);
  static const IconData reload = const _IconData(0xe0b3);
  static const IconData resizeBoth = const _IconData(0xe0b4);
  static const IconData resizeHeight = const _IconData(0xe0b5);
  static const IconData resizeWidth = const _IconData(0xe0b6);
  static const IconData rssAlt = const _IconData(0xe0b7);
  static const IconData rss = const _IconData(0xe0b8);
  static const IconData script = const _IconData(0xe0b9);
  static const IconData shareBoxed = const _IconData(0xe0ba);
  static const IconData share = const _IconData(0xe0bb);
  static const IconData shield = const _IconData(0xe0bc);
  static const IconData signal = const _IconData(0xe0bd);
  static const IconData signpost = const _IconData(0xe0be);
  static const IconData sortAscending = const _IconData(0xe0bf);
  static const IconData sortDescending = const _IconData(0xe0c0);
  static const IconData spreadsheet = const _IconData(0xe0c1);
  static const IconData star = const _IconData(0xe0c2);
  static const IconData sun = const _IconData(0xe0c3);
  static const IconData tablet = const _IconData(0xe0c4);
  static const IconData tag = const _IconData(0xe0c5);
  static const IconData tags = const _IconData(0xe0c6);
  static const IconData target = const _IconData(0xe0c7);
  static const IconData task = const _IconData(0xe0c8);
  static const IconData terminal = const _IconData(0xe0c9);
  static const IconData text = const _IconData(0xe0ca);
  static const IconData thumbDown = const _IconData(0xe0cb);
  static const IconData thumbUp = const _IconData(0xe0cc);
  static const IconData timer = const _IconData(0xe0cd);
  static const IconData transfer = const _IconData(0xe0ce);
  static const IconData trash = const _IconData(0xe0cf);
  static const IconData underline = const _IconData(0xe0d0);
  static const IconData verticalAlignBottom = const _IconData(0xe0d1);
  static const IconData verticalAlignCenter = const _IconData(0xe0d2);
  static const IconData verticalAlignTop = const _IconData(0xe0d3);
  static const IconData video = const _IconData(0xe0d4);
  static const IconData volumeHigh = const _IconData(0xe0d5);
  static const IconData volumeLow = const _IconData(0xe0d6);
  static const IconData volumeOff = const _IconData(0xe0d7);
  static const IconData warning = const _IconData(0xe0d8);
  static const IconData wifi = const _IconData(0xe0d9);
  static const IconData wrench = const _IconData(0xe0da);
  static const IconData x = const _IconData(0xe0db);
  static const IconData yen = const _IconData(0xe0dc);
  static const IconData zoomIn = const _IconData(0xe0dd);
  static const IconData zoomOut = const _IconData(0xe0de);
}

class _IconData extends IconData {
  const _IconData(int codePoint) : super(codePoint, fontFamily: 'OpenIconic');
}

==> open_iconic_flutter-0.2.0.tar.gz: lib/open_iconic_flutter.dart <==
library open_iconic_flutter;

import 'package:flutter/material.dart';

class OpenIconicIcons {
  static const IconData accountLogin = const _IconData(0xe000);
  static const IconData accountLogout = const _IconData(0xe001);
  static const IconData actionRedo = const _IconData(0xe002);
  static const IconData actionUndo = const _IconData(0xe003);
  static const IconData alignCenter = const _IconData(0xe004);
  static const IconData alignLeft = const _IconData(0xe005);
  static const IconData alignRight = const _IconData(0xe006);
  static const IconData aperture = const _IconData(0xe007);
  static const IconData arrowBottom = const _IconData(0xe008);
  static const IconData arrowCircleBottom = const _IconData(0xe009);
  static const IconData arrowCircleLeft = const _IconData(0xe00a);
  static const IconData arrowCircleRight = const _IconData(0xe00b);
  static const IconData arrowCircleTop = const _IconData(0xe00c);
  static const IconData arrowLeft = const _IconData(0xe00d);
  static const IconData arrowRight = const _IconData(0xe00e);
  static const IconData arrowThickBottom = const _IconData(0xe00f);
  static const IconData arrowThickLeft = const _IconData(0xe010);
  static const IconData arrowThickRight = const _IconData(0xe011);
  static const IconData arrowThickTop = const _IconData(0xe012);
  static const IconData arrowTop = const _IconData(0xe013);
  static const IconData audioSpectrum = const _IconData(0xe014);
  static const IconData audio = const _IconData(0xe015);
  static const IconData badge = const _IconData(0xe016);
  static const IconData ban = const _IconData(0xe017);
  static const IconData barChart = const _IconData(0xe018);
  static const IconData basket = const _IconData(0xe019);
  static const IconData batteryEmpty = const _IconData(0xe01a);
  static const IconData batteryFull = const _IconData(0xe01b);
  static const IconData beaker = const _IconData(0xe01c);
  static const IconData bell = const _IconData(0xe01d);
  static const IconData bluetooth = const _IconData(0xe01e);
  static const IconData bold = const _IconData(0xe01f);
  static const IconData bolt = const _IconData(0xe020);
  static const IconData book = const _IconData(0xe021);
  static const IconData bookmark = const _IconData(0xe022);
  static const IconData box = const _IconData(0xe023);
  static const IconData briefcase = const _IconData(0xe024);
  static const IconData britishPound = const _IconData(0xe025);
  static const IconData browser = const _IconData(0xe026);
  static const IconData brush = const _IconData(0xe027);
  static const IconData bug = const _IconData(0xe028);
  static const IconData bullhorn = const _IconData(0xe029);
  static const IconData calculator = const _IconData(0xe02a);
  static const IconData calendar = const _IconData(0xe02b);
  static const IconData cameraSlr = const _IconData(0xe02c);
  static const IconData caretBottom = const _IconData(0xe02d);
  static const IconData caretLeft = const _IconData(0xe02e);
  static const IconData caretRight = const _IconData(0xe02f);
  static const IconData caretTop = const _IconData(0xe030);
  static const IconData cart = const _IconData(0xe031);
  static const IconData chat = const _IconData(0xe032);
  static const IconData check = const _IconData(0xe033);
  static const IconData chevronBottom = const _IconData(0xe034);
  static const IconData chevronLeft = const _IconData(0xe035);
  static const IconData chevronRight = const _IconData(0xe036);
  static const IconData chevronTop = const _IconData(0xe037);
  static const IconData circleCheck = const _IconData(0xe038);
  static const IconData circleX = const _IconData(0xe039);
  static const IconData clipboard = const _IconData(0xe03a);
  static const IconData clock = const _IconData(0xe03b);
  static const IconData cloudDownload = const _IconData(0xe03c);
  static const IconData cloudUpload = const _IconData(0xe03d);
  static const IconData cloud = const _IconData(0xe03e);
  static const IconData cloudy = const _IconData(0xe03f);
  static const IconData code = const _IconData(0xe040);
  static const IconData cog = const _IconData(0xe041);
  static const IconData collapseDown = const _IconData(0xe042);
  static const IconData collapseLeft = const _IconData(0xe043);
  static const IconData collapseRight = const _IconData(0xe044);
  static const IconData collapseUp = const _IconData(0xe045);
  static const IconData command = const _IconData(0xe046);
  static const IconData commentSquare = const _IconData(0xe047);
  static const IconData compass = const _IconData(0xe048);
  static const IconData contrast = const _IconData(0xe049);
  static const IconData copywriting = const _IconData(0xe04a);
  static const IconData creditCard = const _IconData(0xe04b);
  static const IconData crop = const _IconData(0xe04c);
  static const IconData dashboard = const _IconData(0xe04d);
  static const IconData dataTransferDownload = const _IconData(0xe04e);
  static const IconData dataTransferUpload = const _IconData(0xe04f);
  static const IconData delete = const _IconData(0xe050);
  static const IconData dial = const _IconData(0xe051);
  static const IconData document = const _IconData(0xe052);
  static const IconData dollar = const _IconData(0xe053);
  static const IconData doubleQuoteSansLeft = const _IconData(0xe054);
  static const IconData doubleQuoteSansRight = const _IconData(0xe055);
  static const IconData doubleQuoteSerifLeft = const _IconData(0xe056);
  static const IconData doubleQuoteSerifRight = const _IconData(0xe057);
  static const IconData droplet = const _IconData(0xe058);
  static const IconData eject = const _IconData(0xe059);
  static const IconData elevator = const _IconData(0xe05a);
  static const IconData ellipses = const _IconData(0xe05b);
  static const IconData envelopeClosed = const _IconData(0xe05c);
  static const IconData envelopeOpen = const _IconData(0xe05d);
  static const IconData euro = const _IconData(0xe05e);
  static const IconData excerpt = const _IconData(0xe05f);
  static const IconData expandDown = const _IconData(0xe060);
  static const IconData expandLeft = const _IconData(0xe061);
  static const IconData expandRight = const _IconData(0xe062);
  static const IconData expandUp = const _IconData(0xe063);
  static const IconData externalLink = const _IconData(0xe064);
  static const IconData eye = const _IconData(0xe065);
  static const IconData eyedropper = const _IconData(0xe066);
  static const IconData file = const _IconData(0xe067);
  static const IconData fire = const _IconData(0xe068);
  static const IconData flag = const _IconData(0xe069);
  static const IconData flash = const _IconData(0xe06a);
  static const IconData folder = const _IconData(0xe06b);
  static const IconData fork = const _IconData(0xe06c);
  static const IconData fullscreenEnter = const _IconData(0xe06d);
  static const IconData fullscreenExit = const _IconData(0xe06e);
  static const IconData globe = const _IconData(0xe06f);
  static const IconData graph = const _IconData(0xe070);
  static const IconData gridFourUp = const _IconData(0xe071);
  static const IconData gridThreeUp = const _IconData(0xe072);
  static const IconData gridTwoUp = const _IconData(0xe073);
  static const IconData hardDrive = const _IconData(0xe074);
  static const IconData header = const _IconData(0xe075);
  static const IconData headphones = const _IconData(0xe076);
  static const IconData heart = const _IconData(0xe077);
  static const IconData home = const _IconData(0xe078);
  static const IconData image = const _IconData(0xe079);
  static const IconData inbox = const _IconData(0xe07a);
  static const IconData infinity = const _IconData(0xe07b);
  static const IconData info = const _IconData(0xe07c);
  static const IconData italic = const _IconData(0xe07d);
  static const IconData justifyCenter = const _IconData(0xe07e);
  static const IconData justifyLeft = const _IconData(0xe07f);
  static const IconData justifyRight = const _IconData(0xe080);
  static const IconData key = const _IconData(0xe081);
  static const IconData laptop = const _IconData(0xe082);
  static const IconData layers = const _IconData(0xe083);
  static const IconData lightbulb = const _IconData(0xe084);
  static const IconData linkBroken = const _IconData(0xe085);
  static const IconData linkIntact = const _IconData(0xe086);
  static const IconData listRich = const _IconData(0xe087);
  static const IconData list = const _IconData(0xe088);
  static const IconData location = const _IconData(0xe089);
  static const IconData lockLocked = const _IconData(0xe08a);
  static const IconData lockUnlocked = const _IconData(0xe08b);
  static const IconData loopCircular = const _IconData(0xe08c);
  static const IconData loopSquare = const _IconData(0xe08d);
  static const IconData loop = const _IconData(0xe08e);
  static const IconData magnifyingGlass = const _IconData(0xe08f);
  static const IconData mapMarker = const _IconData(0xe090);
  static const IconData map = const _IconData(0xe091);
  static const IconData mediaPause = const _IconData(0xe092);
  static const IconData mediaPlay = const _IconData(0xe093);
  static const IconData mediaRecord = const _IconData(0xe094);
  static const IconData mediaSkipBackward = const _IconData(0xe095);
  static const IconData mediaSkipForward = const _IconData(0xe096);
  static const IconData mediaStepBackward = const _IconData(0xe097);
  static const IconData mediaStepForward = const _IconData(0xe098);
  static const IconData mediaStop = const _IconData(0xe099);
  static const IconData medicalCross = const _IconData(0xe09a);
  static const IconData menu = const _IconData(0xe09b);
  static const IconData microphone = const _IconData(0xe09c);
  static const IconData minus = const _IconData(0xe09d);
  static const IconData monitor = const _IconData(0xe09e);
  static const IconData moon = const _IconData(0xe09f);
  static const IconData move = const _IconData(0xe0a0);
  static const IconData musicalNote = const _IconData(0xe0a1);
  static const IconData paperclip = const _IconData(0xe0a2);
  static const IconData pencil = const _IconData(0xe0a3);
  static const IconData people = const _IconData(0xe0a4);
  static const IconData person = const _IconData(0xe0a5);
  static const IconData phone = const _IconData(0xe0a6);
  static const IconData pieChart = const _IconData(0xe0a7);
  static const IconData pin = const _IconData(0xe0a8);
  static const IconData playCircle = const _IconData(0xe0a9);
  static const IconData plus = const _IconData(0xe0aa);
  static const IconData powerStandby = const _IconData(0xe0ab);
  static const IconData print = const _IconData(0xe0ac);
  static const IconData project = const _IconData(0xe0ad);
  static const IconData pulse = const _IconData(0xe0ae);
  static const IconData puzzlePiece = const _IconData(0xe0af);
  static const IconData questionMark = const _IconData(0xe0b0);
  static const IconData rain = const _IconData(0xe0b1);
  static const IconData random = const _IconData(0xe0b2);
  static const IconData reload = const _IconData(0xe0b3);
  static const IconData resizeBoth = const _IconData(0xe0b4);
  static const IconData resizeHeight = const _IconData(0xe0b5);
  static const IconData resizeWidth = const _IconData(0xe0b6);
  static const IconData rssAlt = const _IconData(0xe0b7);
  static const IconData rss = const _IconData(0xe0b8);
  static const IconData script = const _IconData(0xe0b9);
  static const IconData shareBoxed = const _IconData(0xe0ba);
  static const IconData share = const _IconData(0xe0bb);
  static const IconData shield = const _IconData(0xe0bc);
  static const IconData signal = const _IconData(0xe0bd);
  static const IconData signpost = const _IconData(0xe0be);
  static const IconData sortAscending = const _IconData(0xe0bf);
  static const IconData sortDescending = const _IconData(0xe0c0);
  static const IconData spreadsheet = const _IconData(0xe0c1);
  static const IconData star = const _IconData(0xe0c2);
  static const IconData sun = const _IconData(0xe0c3);
  static const IconData tablet = const _IconData(0xe0c4);
  static const IconData tag = const _IconData(0xe0c5);
  static const IconData tags = const _IconData(0xe0c6);
  static const IconData target = const _IconData(0xe0c7);
  static const IconData task = const _IconData(0xe0c8);
  static const IconData terminal = const _IconData(0xe0c9);
  static const IconData text = const _IconData(0xe0ca);
  static const IconData thumbDown = const _IconData(0xe0cb);
  static const IconData thumbUp = const _IconData(0xe0cc);
  static const IconData timer = const _IconData(0xe0cd);
  static const IconData transfer = const _IconData(0xe0ce);
  static const IconData trash = const _IconData(0xe0cf);
  static const IconData underline = const _IconData(0xe0d0);
  static const IconData verticalAlignBottom = const _IconData(0xe0d1);
  static const IconData verticalAlignCenter = const _IconData(0xe0d2);
  static const IconData verticalAlignTop = const _IconData(0xe0d3);
  static const IconData video = const _IconData(0xe0d4);
  static const IconData volumeHigh = const _IconData(0xe0d5);
  static const IconData volumeLow = const _IconData(0xe0d6);
  static const IconData volumeOff = const _IconData(0xe0d7);
  static const IconData warning = const _IconData(0xe0d8);
  static const IconData wifi = const _IconData(0xe0d9);
  static const IconData wrench = const _IconData(0xe0da);
  static const IconData x = const _IconData(0xe0db);
  static const IconData yen = const _IconData(0xe0dc);
  static const IconData zoomIn = const _IconData(0xe0dd);
  static const IconData zoomOut = const _IconData(0xe0de);
}

class _IconData extends IconData {
  const _IconData(int codePoint)
      : super(
          codePoint,
          fontFamily: 'OpenIconic',
          fontPackage: 'open_iconic_flutter',
        );
}
